<?php
add_action( 'after_setup_theme', 'specialty_setup' );
if ( ! function_exists( 'specialty_setup' ) ) :
	function specialty_setup() {

		$GLOBALS['content_width'] = apply_filters( 'specialty_content_width', 750 );

		if ( ! defined( 'SPECIALTY_NAME' ) ) {
			define( 'SPECIALTY_NAME', 'specialty' );
		}
		if ( ! defined( 'SPECIALTY_WHITELABEL' ) ) {
			// Set the following to true, if you want to remove any user-facing CSSIgniter traces.
			define( 'SPECIALTY_WHITELABEL', false );
		}

		load_theme_textdomain( 'specialty', get_template_directory() . '/languages' );

		/*
		 * Theme supports.
		 */
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'custom-logo', array(
			'height'      => 30,
			'width'       => 185,
			'flex-height' => true,
			'flex-width'  => true,
		) );

		add_theme_support( 'custom-background' );

		/*
		 * Image sizes.
		 */
		set_post_thumbnail_size( 850, 450, true );
		add_image_size( 'specialty_entry_item', 264, 140, true );
		add_image_size( 'specialty_fullwidth', 1140, 550, true );
		add_image_size( 'specialty_fullwidth_narrow', 950, 450, true );
		add_image_size( 'specialty_wpjm_company_logo', 200, 0, false );
		add_image_size( 'specialty_hero', 1920, 500, true );

		/*
		 * Navigation menus.
		 */
		register_nav_menus( array(
			'main_menu' => esc_html__( 'Main Menu', 'specialty' ),
		) );


		/*
		 * Default hooks
		 */
		// Prints the inline JS scripts that are registered for printing, and removes them from the queue.
		add_action( 'admin_footer', 'specialty_print_inline_js' );
		add_action( 'wp_footer', 'specialty_print_inline_js' );

		// Handle the dismissible sample content notice.
		add_action( 'admin_notices', 'specialty_admin_notice_sample_content' );
		add_action( 'wp_ajax_specialty_dismiss_sample_content', 'specialty_ajax_dismiss_sample_content' );

		// Wraps post counts in span.ci-count
		// Needed for the default widgets, however more appropriate filters don't exist.
		add_filter( 'get_archives_link', 'specialty_wrap_archive_widget_post_counts_in_span', 10, 2 );
		add_filter( 'wp_list_categories', 'specialty_wrap_category_widget_post_counts_in_span', 10, 2 );
	}
endif;

/**
 * Theme helper functions.
 */
require_once get_theme_file_path( '/inc/helpers.php' );

/**
 * Post meta helper functions.
 */
require_once get_theme_file_path( '/inc/helpers-post-meta.php' );

/**
 * Default theme hooks.
 */
require_once get_theme_file_path( '/inc/default-hooks.php' );

/**
 * Layout related functionality.
 */
require_once get_theme_file_path( '/inc/layout.php' );

/**
 * Theme scripts and styles.
 */
require_once get_theme_file_path( '/inc/scripts-styles.php' );

/**
 * Sidebars and widgets.
 */
require_once get_theme_file_path( '/inc/sidebars-widgets.php' );

/**
 * Sanitization functions.
 */
require_once get_theme_file_path( '/inc/sanitization.php' );

/**
 * Functions handling version upgrades.
 */
require_once get_theme_file_path( '/inc/upgrade.php' );

/**
 * Customizer related functions.
 */
require_once get_theme_file_path( '/inc/customizer/customizer.php' );

/**
 * WP Job Manager compatibility.
 */
require_once get_theme_file_path( '/inc/wp-job-manager.php' );

/**
 * Custom fields for the page post type.
 */
require_once get_theme_file_path( '/inc/custom-fields-page.php' );

/**
 * User onboarding.
 */
require_once get_theme_file_path( '/inc/onboarding/onboarding.php' );