<?php
add_action( 'customize_register', 'specialty_customize_register', 100 );
/**
 * Registers all theme-related options to the Customizer.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function specialty_customize_register( $wpc ) {

	// Partial for various settings that affect the customizer styles, but can't have a dedicated icon, e.g. 'limit_logo_size'
	$wpc->selective_refresh->add_partial( 'theme_style', array(
		'selector'            => '#specialty-style-inline-css',
		'render_callback'     => 'specialty_get_all_customizer_css',
		'settings'            => array_keys( specialty_get_registered_typography_controls() ),
		'container_inclusive' => false,
	) );

	$wpc->selective_refresh->add_partial( 'theme_gfonts', array(
		'selector'            => '#specialty-user-google-fonts-css',
		'render_callback'     => 'specialty_customize_preview_google_fonts',
		'settings'            => array_keys( specialty_get_registered_typography_controls() ),
		'container_inclusive' => true,
	) );

	$wpc->get_panel( 'nav_menus' )->priority = 20;

	$wpc->add_section( 'layout', array(
		'title'    => esc_html_x( 'Layout Options', 'customizer section title', 'specialty' ),
		'priority' => 30,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/layout.php' );

	$wpc->add_section( 'single_post', array(
		'title'       => esc_html_x( 'Posts Options', 'customizer section title', 'specialty' ),
		'description' => esc_html__( 'These options affect your individual posts.', 'specialty' ),
		'priority'    => 40,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/single-post.php' );

	$wpc->add_panel( 'theme_colors', array(
		'title'    => esc_html_x( 'Colors', 'customizer section title', 'specialty' ),
		'priority' => 50,
	) );

	// Rename & Reposition the Colors section.
	$wpc->get_section( 'colors' )->title    = esc_html_x( 'Global', 'customizer section title', 'specialty' );
	$wpc->get_section( 'colors' )->priority = 10;
	$wpc->get_section( 'colors' )->panel    = 'theme_colors';
	require_once get_theme_file_path( '/inc/customizer/sections/colors-global.php' );

	$wpc->add_section( 'colors_header', array(
		'title'    => esc_html_x( 'Header', 'customizer section title', 'specialty' ),
		'priority' => 20,
		'panel'    => 'theme_colors',
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/colors-header.php' );

	$wpc->add_section( 'colors_hero', array(
		'title'    => esc_html_x( 'Hero', 'customizer section title', 'specialty' ),
		'priority' => 30,
		'panel'    => 'theme_colors',
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/colors-hero.php' );

	$wpc->add_section( 'colors_sidebar', array(
		'title'    => esc_html_x( 'Sidebar', 'customizer section title', 'specialty' ),
		'priority' => 40,
		'panel'    => 'theme_colors',
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/colors-sidebar.php' );

	$wpc->add_section( 'typography', array(
		'title'    => esc_html_x( 'Typography Options', 'customizer section title', 'specialty' ),
		'priority' => 60,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/typography.php' );

	// The following line doesn't work in a some PHP versions. Apparently, get_panel( 'widgets' ) returns an array,
	// therefore a cast to object is needed. http://wordpress.stackexchange.com/questions/160987/warning-creating-default-object-when-altering-customize-panels
	//$wpc->get_panel( 'widgets' )->priority = 50;
	$panel_widgets = (object) $wpc->get_panel( 'widgets' );
	$panel_widgets->priority = 70;

	$wpc->add_section( 'social', array(
		'title'       => esc_html_x( 'Social Networks', 'customizer section title', 'specialty' ),
		'description' => esc_html__( 'Enter your social network URLs. Leaving a URL empty will hide its respective icon.', 'specialty' ),
		'priority'    => 80,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/socials.php' );

	$wpc->add_section( 'titles', array(
		'title'    => esc_html_x( 'Titles', 'customizer section title', 'specialty' ),
		'priority' => 90,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/titles.php' );

	$wpc->add_section( 'theme_jobs', array(
		'title'       => esc_html_x( 'Job Listing Options', 'customizer section title', 'specialty' ),
		/* translators: %s is a url. */
		'description' => wp_kses( sprintf( __( 'All options require that the <a href="%s">WP Job Manager</a> plugin is active.', 'specialty' ), 'https://wordpress.org/plugins/wp-job-manager/' ), specialty_get_allowed_tags( 'guide' ) ),
		'priority'    => 100,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/theme-jobs.php' );

	$wpc->add_section( 'footer', array(
		'title'    => esc_html_x( 'Footer Options', 'customizer section title', 'specialty' ),
		'priority' => 110,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/footer.php' );

	// Section 'static_front_page' is not defined when there are no pages.
	if ( get_pages() ) {
		$wpc->get_section( 'static_front_page' )->priority = 120;
	}

	$wpc->add_section( 'other', array(
		'title'       => esc_html_x( 'Other', 'customizer section title', 'specialty' ),
		'description' => esc_html__( 'Other options affecting the whole site.', 'specialty' ),
		'priority'    => 130,
	) );
	require_once get_theme_file_path( '/inc/customizer/sections/other.php' );


	//
	// title_tagline Section
	//
	require_once get_theme_file_path( '/inc/customizer/sections/site-tagline.php' );
}

add_action( 'customize_register', 'specialty_customize_register_custom_controls', 9 );
/**
 * Registers custom Customizer controls.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function specialty_customize_register_custom_controls( $wpc ) {
	require get_template_directory() . '/inc/customizer/customizer-controls/static-text.php';
	require get_template_directory() . '/inc/customizer/customizer-controls/alpha-color-picker/alpha-color-picker.php';

	require_once get_theme_file_path( '/inc/customizer/customizer-controls/typography/typography.php' );
	$wpc->register_control_type( 'Specialty_Customize_Typography_Control' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function specialty_customize_preview_js() {

	// Generic preview code.
	wp_enqueue_script( 'specialty-customizer-preview', get_theme_file_uri( '/inc/customizer/preview/preview.js' ), array( 'jquery' ), specialty_asset_version(), true );

	// Options-specific preview code.
	wp_enqueue_script( 'specialty-customizer-preview-typography', get_theme_file_uri( '/inc/customizer/preview/typography-preview.js' ), array( 'jquery' ), specialty_asset_version(), true );
	wp_enqueue_script( 'specialty-customizer-preview-colors', get_theme_file_uri( '/inc/customizer/preview/colors-preview.js' ), array( 'jquery' ), specialty_asset_version(), true );
}
add_action( 'customize_preview_init', 'specialty_customize_preview_js' );

function specialty_customize_controls_js() {
	wp_enqueue_style( 'specialty-customizer-controls', get_theme_file_uri( '/inc/customizer/customizer-controls/style.css' ), array(), wp_get_theme()->get( 'Version' ) );
}
add_action( 'customize_controls_enqueue_scripts', 'specialty_customize_controls_js' );

function specialty_typography_control_defaults_empty_breakpoints( $override_breakpoints = array() ) {
	$defaults = array(
		'desktop' => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
		'tablet'  => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
		'mobile'  => array(
			'family'     => '',
			'variant'    => '',
			'size'       => '',
			'lineHeight' => '',
			'transform'  => '',
			'spacing'    => '',
			'is_gfont'   => false,
		),
	);

	$return = array();
	foreach ( $defaults as $breakpoint => $values ) {
		if ( isset( $override_breakpoints[ $breakpoint ] ) && is_array( $override_breakpoints[ $breakpoint ] ) ) {
			$return[ $breakpoint ] = array_merge( $values, $override_breakpoints[ $breakpoint ] );
		} else {
			$return[ $breakpoint ] = $values;
		}
	}

	return $return;
}

function specialty_sanitize_typography_control_breakpoints( $values ) {
	$defaults = specialty_typography_control_defaults_empty_breakpoints();

	if ( ! empty( $values ) && is_string( $values ) ) {
		$values = json_decode( $values, true );
	}

	if ( ! is_array( $values ) ) {
		return $defaults;
	}

	$values = wp_parse_args( $values, $defaults );

	foreach ( $values as $breakpoint => $value ) {
		if ( ! array_key_exists( $breakpoint, $defaults ) ) {
			unset( $values[ $breakpoint ] );
		}
	}

	$new_values = array();

	foreach ( $values as $breakpoint => $breakpoint_values ) {
		if ( array_key_exists( $breakpoint, $defaults ) ) {
			$new_breakpoint_values = wp_parse_args( $breakpoint_values, $defaults[ $breakpoint ] );

			$new_breakpoint_values['family']     = sanitize_text_field( $new_breakpoint_values['family'] );
			$new_breakpoint_values['variant']    = sanitize_text_field( $new_breakpoint_values['variant'] );
			$new_breakpoint_values['size']       = specialty_sanitize_intval_or_empty( $new_breakpoint_values['size'] );
			$new_breakpoint_values['lineHeight'] = specialty_sanitize_floatval_or_empty( $new_breakpoint_values['lineHeight'] );
			$new_breakpoint_values['transform']  = sanitize_text_field( $new_breakpoint_values['transform'] );
			$new_breakpoint_values['spacing']    = specialty_sanitize_floatval_or_empty( $new_breakpoint_values['spacing'] );
			$new_breakpoint_values['is_gfont']   = (bool) intval( $new_breakpoint_values['is_gfont'] );

			$new_values[ $breakpoint ] = $new_breakpoint_values;
		}
	}

	return $new_values;
}

if ( ! function_exists( 'specialty_customize_preview_google_fonts' ) ) {
	function specialty_customize_preview_google_fonts( $_this, $container_context ) {
		specialty_enqueue_google_fonts();
		wp_print_styles( 'specialty-user-google-fonts' );
	}
}

/**
 * Customizer defaults.
 */
require_once get_theme_file_path( '/inc/customizer/defaults.php' );

/**
 * Fonts list.
 */
require_once get_theme_file_path( '/inc/customizer/class-fonts-list.php' );

/**
 * CSS Generator.
 */
require_once get_theme_file_path( '/inc/customizer/class-specialty-customizer-css-generator.php' );

/**
 * Customizer style generator.
 */
require_once get_theme_file_path( '/inc/customizer/style-generator.php' );
