/**
 * Base Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Base Theme Customizer preview reload changes asynchronously.
 *
 * https://developer.wordpress.org/themes/customize-api/tools-for-improved-user-experience/#using-postmessage-for-improved-setting-previewing
 */

(function ($) {
	function createStyleSheet(settingName, styles) {
		var $styleElement;

		style = '<style class="' + settingName + '">';
		style += styles.reduce(function (rules, style) {
			rules += style.selectors + '{' + style.property + ':' + style.value + ';} ';
			return rules;
		}, '');
		style += '</style>';

		$styleElement = $('.' + settingName);

		if ($styleElement.length) {
			$styleElement.replaceWith(style);
		} else {
			$('head').append(style);
		}
	}

	//
	// Global Colors
	//

	wp.customize('site_accent_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_accent_color', [
				{
					property: 'color',
					value: to,
					selectors: 'a, a:hover,.text-theme,.navigation-main li li:hover > a,.navigation-main li li > a:focus,.navigation-main li .current-menu-item > a,.navigation-main li .current-menu-parent > a,.navigation-main li .current-menu-ancestor > a,.widget_meta li a:hover,.widget_pages li a:hover,.widget_categories li a:hover,.widget_archive li a:hover,.widget_nav_menu li a:hover,.widget_recent_entries li a:hover,.btn-white.btn-transparent:hover'
				},
				{
					property: 'background-color',
					value: to,
					selectors: '.chosen-container .chosen-results li.highlighted,.item-color,.item-badge,.list-item-callout,.list-item-secondary-wrap,.item-filter-tag-bg,.checkbox-filter:checked + label::before,.navigation a:hover,.navigation .current,.social-icon:hover,.navigation-main > li.menu-item-btn > a:hover,.select2-container .select2-results .select2-results__option--highlighted'
				},
				{
					property: 'border-color',
					value: to,
					selectors: 'input:hover,input:focus,textarea:hover,textarea:focus,.social-icon:hover,.navigation-main > li.menu-item-btn > a,.item-listing::after,ul.job_listings::after'
				},
				{
					property: 'border-top-color',
					value: to,
					selectors: '.item-listing::after,ul.job_listings::after'
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.navigation-main > li:hover > a,.navigation-main > li > a:focus,.navigation-main > .current-menu-item > a,.navigation-main > .current-menu-parent > a,.navigation-main > .current-menu-ancestor > a'
				},
			]);
		});
	});

	wp.customize('site_text_on_accent_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_text_on_accent_color', [
				{
					property: 'color',
					value: to,
					selectors: '.item-badge,.item-badge:hover,.list-item-callout .list-item-title,.list-item-callout .list-item-time,.list-item-callout .list-item-company,.checkbox-filter-label::after,.navigation a:hover,.navigation .current'
				},
			]);
		});
	});

	wp.customize('site_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_text_color', [
				{
					property: 'color',
					value: to,
					selectors: 'body,input,textarea,select,.ci-select::after,.widget .instagram-pics li a,.chosen-container,.chosen-container .chosen-single,.chosen-container-multi .chosen-choices,.section-title-compliment a,.entry-share,.navigation a,.navigation span,.ci-select .select2-container .select2-selection.select2-selection--multiple select2-selection_choice,blockquote cite,.ci-select select,.mobile-trigger:hover,.mobile-trigger:focus,.list-item-time,.list-item-company,.checkbox-filter-label,.social-icon,.widget_meta li a,.widget_pages li a,.widget_categories li a,.widget_archive li a,.widget_nav_menu li a,.widget_recent_entries li a,.text-secondary,.comment-author,.footer-copy,.content-wrap-footer,.entry-meta,.navigation a,.navigation span,.list-item-location,.widget-title'
				},
				{
					property: 'border-color',
					value: to,
					selectors: '.social-icon'
				},
			]);
		});
	});

	wp.customize('site_border_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_border_color', [
				{
					property: 'border-color',
					value: to,
					selectors: 'input,textarea,select,.widget select,.ci-select select,.chosen-container .chosen-single,.chosen-drop,.chosen-container-single .chosen-search input[type="text"],.chosen-container-multi .chosen-choices,.chosen-container-active.chosen-with-drop .chosen-single,input:hover,input:focus,textarea:hover,textarea:focus'
				},
				{
					property: 'border-top-color',
					value: to,
					selectors: '.footer-copy,.mobile-triggers'
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.widget_recent_comments li,.company_video,.widget ul.job_listings li.job_listing,.content-wrap,ul.job_listings li.list-item.job_listing,.list-item-secondary-wrap:last-child,.item-filter,.search-notice,.entry-item,.navigation a,.navigation span,.card-info-thumb,.callout-wrapper'
				},
				{
					property: 'border-left-color',
					value: to,
					selectors: 'blockquote'
				},
				{
					property: 'border-right-color',
					value: to,
					selectors: '.mobile-trigger:first-child'
				},
			]);
		});
	});

	wp.customize('site_element_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_element_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.company_video,.widget ul.job_listings li.job_listing,.content-wrap,.list-item:not(.list-item-callout),.no_job_listings_found,.item-filter,.entry-item,.navigation a,.navigation span,.card-info-thumb,.callout-wrapper'
				},
			]);
		});
	});

	wp.customize('button_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('button_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.btn,.button,.comment-reply-link,input[type="submit"],input[type="reset"],button'
				},
				{
					property: 'background-color',
					value: 'transparent',
					selectors: '.btn-transparent'
				},
				{
					property: 'color',
					value: to,
					selectors: '.btn.btn-transparent'
				},
				{
					property: 'border-color',
					value: to,
					selectors: '.btn-transparent'
				},
			]);
		});
	});

	wp.customize('button_hover_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('button_hover_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.btn:hover,.button:hover,.comment-reply-link:hover,input[type="submit"]:hover,input[type="reset"]:hover,button:hover'
				},
			]);
		});
	});

	wp.customize('button_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('button_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.btn,.button,.comment-reply-link,input[type="submit"],input[type="reset"],button'
				},
			]);
		});
	});

	wp.customize('button_hover_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('button_hover_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.btn:hover,.button:hover,.comment-reply-link:hover,input[type="submit"]:hover,input[type="reset"]:hover,button:hover'
				},
			]);
		});
	});

	wp.customize('footer_background_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('footer_background_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.footer'
				},
			]);
		});
	});

	//
	// Header Colors
	//
	wp.customize('head_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('head_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.header,.site-logo a,.site-tagline,.navigation-main > li > a'
				},
			]);
		});
	});

	wp.customize('head_text_hover_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('head_text_hover_color', [
				{
					property: 'color',
					value: to,
					selectors: '.site-logo a:hover,.navigation-main > li:hover > a,.navigation-main > li > a:focus,.navigation-main > .current-menu-item > a,.navigation-main > .current-menu-parent > a,.navigation-main > .current-menu-ancestor > a'
				},
			]);
		});
	});

	wp.customize('head_subnav_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('head_subnav_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.navigation-main ul'
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.navigation-main > li > ul::before'
				},
			]);
		});
	});

	wp.customize('head_subnav_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('head_subnav_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.navigation-main li li a'
				},
			]);
		});
	});

	wp.customize('head_subnav_text_hover_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('head_subnav_text_hover_color', [
				{
					property: 'color',
					value: to,
					selectors: '.navigation-main li li:hover > a,.navigation-main li li > a:focus,.navigation-main li .current-menu-item > a,.navigation-main li .current-menu-parent > a,.navigation-main li .current-menu-ancestor > a'
				},
			]);
		});
	});

	wp.customize('head_subnav_border_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('head_subnav_border_color', [
				{
					property: 'border-color',
					value: to,
					selectors: '.navigation-main li li a'
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.navigation-main ul'
				},
			]);
		});
	});

	//
	// Sidebar Colors
	//
	wp.customize('sidebar_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar,.sidebar .widget-title'
				},
			]);
		});
	});

	wp.customize('sidebar_link_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_link_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar a:not(.btn),.sidebar .widget_meta li a,.sidebar .widget_pages li a,.sidebar .widget_categories li a,.sidebar .widget_archive li a,.sidebar .widget_nav_menu li a,.sidebar .widget_recent_entries li a,.sidebar .widget_product_categories li a,.sidebar .widget_layered_nav li a,.sidebar .widget_rating_filter li a,.sidebar .sidebar .product_list_widget .product-title'
				},
			]);
		});
	});

	wp.customize('sidebar_link_hover_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_link_hover_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar a:not(.btn):hover,.sidebar .widget_meta li a:hover,.sidebar .widget_pages li a:hover,.sidebar .widget_categories li a:hover,.sidebar .widget_archive li a:hover,.sidebar .widget_nav_menu li a:hover,.sidebar .widget_recent_entries li a:hover,.sidebar .widget_product_categories li a:hover,.sidebar .widget_layered_nav li a:hover,.sidebar .widget_rating_filter li a:hover,.sidebar .product_list_widget .product-title:hover'
				},
			]);
		});
	});

	wp.customize('sidebar_border_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_border_color', [
				{
					property: 'border-color',
					value: to,
					selectors: '.sidebar .widget select'
				},
				{
					property: 'border-bottom-color',
					value: to,
					selectors: '.sidebar .widget_recent_comments li,.sidebar .widget_rss li'
				},
			]);
		});
	});

	wp.customize('sidebar_widget_title_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('sidebar_widget_title_color', [
				{
					property: 'color',
					value: to,
					selectors: '.sidebar .widget-title'
				},
			]);
		});
	});

	//
	// Hero Colors
	//
	wp.customize('hero_bg_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('hero_bg_color', [
				{
					property: 'background-color',
					value: to,
					selectors: '.page-hero::before'
				},
			]);
		});
	});

	wp.customize('hero_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('hero_text_color', [
				{
					property: 'color',
					value: to,
					selectors: '.page-hero'
				},
			]);
		});
	});

})(jQuery);
