<?php
add_action( 'wp_head', 'specialty_pingback_header' );
if ( ! function_exists( 'specialty_pingback_header' ) ) :
	/**
	 * Add a pingback url auto-discovery header for singularly identifiable articles.
	 */
	function specialty_pingback_header() {
		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">' . "\n", esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}
endif;


add_filter( 'excerpt_length', 'specialty_excerpt_length' );
if ( ! function_exists( 'specialty_excerpt_length' ) ) :
	function specialty_excerpt_length( $length ) {
		return get_theme_mod( 'excerpt_length', 55 );
	}
endif;


add_filter( 'the_content', 'specialty_lightbox_rel', 12 );
add_filter( 'get_comment_text', 'specialty_lightbox_rel' );
if ( ! function_exists( 'specialty_lightbox_rel' ) ) :
	function specialty_lightbox_rel( $content ) {
		global $post;
		$pattern     = "/<a(.*?)href=('|\")([^>]*).(bmp|gif|jpeg|jpg|png)('|\")(.*?)>(.*?)<\/a>/i";
		$replacement = '<a$1href=$2$3.$4$5 data-lightbox="gal[' . $post->ID . ']"$6>$7</a>';
		$content     = preg_replace( $pattern, $replacement, $content );

		return $content;
	}
endif;

add_filter( 'wp_page_menu', 'specialty_wp_page_menu', 10, 2 );
if ( ! function_exists( 'specialty_wp_page_menu' ) ) :
	function specialty_wp_page_menu( $menu, $args ) {
		preg_match( '#^<div class="(.*?)">(?:.*?)</div>$#', $menu, $matches );
		$menu = preg_replace( '#^<div class=".*?">#', '', $menu, 1 );
		$menu = preg_replace( '#</div>$#', '', $menu, 1 );
		$menu = preg_replace( '#^<ul>#', '<ul class="' . esc_attr( $args['menu_class'] ) . '">', $menu, 1 );

		return $menu;
	}
endif;

add_filter( 'login_url', 'specialty_redirect_login_page', 10, 2 );
if ( ! function_exists( 'specialty_redirect_login_page' ) ) :
	function specialty_redirect_login_page( $login_url, $redirect ) {
		$page_id = get_theme_mod( 'login_page' );
		if ( empty( $page_id ) || intval( $page_id ) <= 0 ) {
			return $login_url;
		}

		$page_id = intval( $page_id );
		$page    = get_post( $page_id );

		if ( is_null( $page ) || ! is_object( $page ) || empty( $page ) ) {
			return $login_url;
		}

		if ( 'template-login.php' !== get_page_template_slug( $page ) ) {
			return $login_url;
		}

		$login_url = get_permalink( $page );
		if ( ! empty( $redirect ) ) {
			$login_url = add_query_arg( 'redirect_to', $redirect, $login_url );
		}

		return $login_url;
	}
endif;

/**
 * Add wrapper to embedded items to apply responsive styling.
 */
add_filter( 'embed_oembed_html', 'specialty_oembed_responsive_wrapper', 10, 4 );
function specialty_oembed_responsive_wrapper( $cache, $url, $attr, $post_ID ) {
	if ( empty( $cache ) ) {
		return $cache;
	}

	$url_patterns = array(
		'youtube.com',
		'youtu.be',
		'youtube-nocookie.com', // This doesn't seem to embed anything.
		'vimeo.com',
		'dailymotion.com',
		'dai.ly', // This doesn't seem to embed anything.
		'hulu.com',
		'wordpress.tv',
		'slideshare.net',
	);

	$match = false;

	foreach ( $url_patterns as $url_pattern ) {
		$pattern = 'https?://.*?' . preg_quote( $url_pattern, '#' );
		if ( preg_match( '#' . $pattern . '#', $url ) ) {
			$match = true;
			break;
		}
	}

	if ( $match ) {
		$cache = '<div class="specialty-responsive-embed">' . $cache . '</div>';
	}

	return $cache;
}

/**
 * Load extra font weight needed by the theme.
 */
add_filter( 'specialty_customizer_css_generator_standard_gfont_weights', 'specialty_extra_gfont_weights' );
function specialty_extra_gfont_weights( $weights ) {
	$extra_weights = array(
		'300',
	);

	$weights = array_merge( $weights, $extra_weights );

	return $weights;
}