<?php
/**
 * Specialty onboarding related code.
 */

if ( ! defined( 'SPECIALTY_WHITELABEL' ) || false === (bool) SPECIALTY_WHITELABEL ) {
	add_filter( 'pt-ocdi/import_files', 'specialty_ocdi_import_files' );
	add_action( 'pt-ocdi/after_import', 'specialty_ocdi_after_import_setup' );
}

add_filter( 'pt-ocdi/timeout_for_downloading_import_file', 'specialty_ocdi_download_timeout' );
function specialty_ocdi_download_timeout( $timeout ) {
	return 60;
}

function specialty_ocdi_import_files( $files ) {
	if ( ! defined( 'SPECIALTY_NAME' ) ) {
		define( 'SPECIALTY_NAME', 'specialty' );
	}

	$demo_dir_url = untrailingslashit( apply_filters( 'specialty_ocdi_demo_dir_url', 'https://www.cssigniter.com/sample_content/' . SPECIALTY_NAME ) );

	$import_notice = __( 'You need to install and activate all required and recommended plugins for the sample content to be imported successfully.', 'specialty' );

	// When having more that one predefined imports, set a preview image, preview URL, and categories for isotope-style filtering.
	$new_files = array(
		array(
			'import_file_name'           => esc_html__( 'Default', 'specialty' ),
			'import_file_url'            => $demo_dir_url . '/content.xml',
			'import_widget_file_url'     => $demo_dir_url . '/widgets.wie',
			'import_customizer_file_url' => $demo_dir_url . '/customizer.dat',
			'import_notice'              => $import_notice,
			'preview_url'                => 'https://www.cssigniter.com/preview/specialty/',
		),
	);

	return array_merge( $files, $new_files );
}

function specialty_ocdi_after_import_setup() {
	// Set up nav menus.
	$main_menu = get_term_by( 'name', 'Menu 1', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
		'main_menu' => $main_menu->term_id,
	) );

	// Set up home and blog pages.
	$front_page_id = get_page_by_title( 'Home' );
	$blog_page_id  = get_page_by_title( 'Blog' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );

	// Try to force a term recount.
	// wp_defer_term_counting( false ) doesn't work properly as there are post imported from different AJAX requests.
	$taxonomies = get_taxonomies( array(), 'names' );
	foreach ( $taxonomies as $taxonomy ) {
		$terms             = get_terms( $taxonomy, array( 'hide_empty' => false ) );
		$term_taxonomy_ids = wp_list_pluck( $terms, 'term_taxonomy_id' );

		wp_update_term_count( $term_taxonomy_ids, $taxonomy );
	}
}

function specialty_get_theme_required_plugins() {
	return apply_filters( 'specialty_theme_required_plugins', array() );
}

function specialty_get_theme_recommended_plugins() {
	return apply_filters( 'specialty_theme_recommended_plugins', array(
		'wp-job-manager'        => array(
			'title'       => __( 'WP Job Manager', 'specialty' ),
			'description' => __( 'WP Job Manager is a lightweight job listing plugin for adding job-board like functionality to your WordPress site. Being shortcode based, it can work with any theme (given a bit of CSS styling) and is really simple to setup.', 'specialty' ),
			'required_by_sample' => true,
		),
		'gutenbee'              => array(
			'title'       => __( 'GutenBee', 'specialty' ),
			'description' => __( 'Premium blocks for WordPress.', 'specialty' ),
		),
		'maxslider'             => array(
			'title'              => __( 'MaxSlider', 'specialty' ),
			'description'        => __( 'Add a custom responsive slider to any page of your website.', 'specialty' ),
		),
		'elementor'             => array(
			'title'              => __( 'Elementor', 'specialty' ),
			'description'        => __( 'Elementor is a front-end drag & drop page builder for WordPress.', 'specialty' ),
			'required_by_sample' => true,
		),
		'audioigniter'          => array(
			'title'       => __( 'AudioIgniter', 'specialty' ),
			'description' => __( 'Probably the most flexible music player plugin for WordPress.', 'specialty' ),
		),
		'wp-smushit'            => array(
			'title'       => __( 'Smush by WPMU DEV', 'specialty' ),
			'description' => __( 'Compress, Optimize and Lazy Load Images.', 'specialty' ),
			'plugin_file' => 'wp-smush.php',
		),
		'wpforms-lite'          => array(
			'title'       => __( 'Contact Form by WPForms', 'specialty' ),
			'description' => __( 'Drag & Drop Form Builder for WordPress.', 'specialty' ),
			'plugin_file' => 'wpforms.php',
			'is_callable' => 'wpforms',
		),
		'one-click-demo-import' => array(
			'title'              => __( 'One Click Demo Import', 'specialty' ),
			'description'        => __( 'Import your demo content, widgets and theme settings with one click.', 'specialty' ),
			'required_by_sample' => true,
		),
	) );
}

add_action( 'init', 'specialty_onboarding_page_init' );
function specialty_onboarding_page_init() {
	$data = array(
		'show_page'                => true,
		'description'              => __( 'Job listing theme for WordPress.', 'specialty' ),
		'default_tab'              => 'recommended_plugins',
		'tabs'                     => array(
			'required_plugins'    => '',
		),
		'required_plugins_page'    => array(
			'plugins' => specialty_get_theme_required_plugins(),
		),
		'recommended_plugins_page' => array(
			'plugins' => specialty_get_theme_recommended_plugins(),
		),

	);

	$onboarding = new Specialty_Onboarding_Page();
	$onboarding->init( apply_filters( 'specialty_onboarding_page_array', $data ) );

//	// Full parameters list. Only use what's required or needs to be overridden.
//	$theme = wp_get_theme();
//	$data  = array(
//		// Required. Turns the onboarding page on/off.
//		'show_page'                => true,
//		// Optional. Turns the redirection to the onboarding page on/off.
//		'redirect_on_activation'   => true,
//		// Optional. The text to be used for the admin menu. If empty, defaults to "About theme_name"
//		/* translators: %s is the theme name. */
//		'menu_title'               => sprintf( __( 'About %s', 'specialty' ), $theme->get( 'Name' ) ),
//		// Optional. The text to be displayed in the page's title tag. If empty, defaults to "About theme_name"
//		/* translators: %s is the theme name. */
//		'page_title'               => sprintf( __( 'About %s', 'specialty' ), $theme->get( 'Name' ) ),
//		// Optional. The onboarding page's title, placeholders available :theme_name:, :theme_version:. If empty, defaults to "Welcome to :theme_name:! - Version :theme_version:"
//		'title'                    => __( 'Welcome to :theme_name:! - Version :theme_version:', 'specialty' ),
//		// Optional. The theme's description. Some HTML is allowed (no p).
//		'description'              => '',
//		// Optional. Boolean. Whether to show the logo. Default: true in normal mode. false if whitelabel.
//		'logo_show'                => defined( 'SPECIALTY_WHITELABEL' ) && SPECIALTY_WHITELABEL ? false : true,
//		// Optional. The logo's image source URL. Defaults to the bundled logo.
//		'logo_src'                 => get_theme_file_uri( '/inc/onboarding/assets/cssigniter_logo.svg' ),
//		// Optional. The logo's link URL. Defaults to 'https://www.cssigniter.com/themes/' . SPECIALTY_NAME . '/'
//		'logo_url'                 => 'https://www.cssigniter.com/themes/' . SPECIALTY_NAME . '/',
//		// Optional. The default active tab. Default 'required_plugins'. Must be one of the keys in the tabs[] array.
//		'default_tab'              => 'required_plugins',
//		// Optional. slug => label pairs for each tab. Empty label to disable. Defaults are as follows:
//		'tabs'                     => array(
//			'theme_variations'    => __( 'Theme Variations', 'specialty' ),
//			'required_plugins'    => __( 'Required Plugins', 'specialty' ),
//			'recommended_plugins' => __( 'Recommended Plugins', 'specialty' ),
//			'sample_content'      => __( 'Sample Content', 'specialty' ),
//			'support'             => __( 'Support', 'specialty' ),
//		),
//		'theme_variations_page'    => array(
//			'reset_mods_button' => true,
//			'variations'        => array(
//				// Each variation is registered as 'slug' => array()
//				'variation-slug' => array(
//					// Required. The variation's title.
//					'title'       => __( 'Variation Title', 'specialty' ),
//					// Optional. The variation's description.
//					'description' => '',
//					// Required. The variation's screenshot. Defaults to /theme-variations/variation-slug/screenshot.png and falls back to the theme's screenshot.
//					'screenshot'  => '',
//				),
//			),
//		),
//		'required_plugins_page'    => array(
//			'plugins' => array(
//				// Each plugin is registered as 'slug' => array(). The slug must match the plugin's directory.
//				'plugin-slug' => array(
//					// Required. The plugin's title.
//					'title'              => __( 'Plugin Title', 'specialty' ),
//					// Optional. The plugin's description, or why the plugin is required.
//					'description'        => '',
//					// Optional. If both 'version' and 'bundle' are set, the theme will prompt for a plugin update if applicable.
//					'version'            => '1.0',
//					// Optional. If true, the plugin zip will be searched in the theme's plugins/ directory, named "plugin-slug.zip". Default false.
//					'bundled'            => false,
//					// Optional. If passed string or array is callable, then the plugin will appear as activated.
//					'is_callable'        => '',
//					// Optional. If not passed, it's assumed to be "plugin-slug.php". Only pass a filename. It gets combined with the plugin slug as needed.
//					'plugin_file'        => '',
//					// Optional. Declares that the plugin must be active for sample content import to succeed. Default false.
//					'required_by_sample' => false,
//				),
//			),
//		),
//		'recommended_plugins_page' => array(
//			'plugins' => array(
//				// Each plugin is registered as 'slug' => array()
//				'plugin-slug' => array(
//					// Required. The plugin's title.
//					'title'              => __( 'Plugin Title', 'specialty' ),
//					// Optional. The plugin's description, or why the plugin is required.
//					'description'        => '',
//					// Optional. If both 'version' and 'bundle' are set, the theme will prompt for a plugin update if applicable.
//					'version'            => '1.0',
//					// Optional. If true, the plugin zip will be searched in the theme's plugins/ directory, named "plugin-slug.zip". Default false.
//					'bundled'            => false,
//					// Optional. If passed string or array is callable, then the plugin will appear as activated.
//					'is_callable'        => '',
//					// Optional. If not passed, it's assumed to be "plugin-slug.php". Only pass a filename. It gets combined with the plugin slug as needed.
//					'plugin_file'        => '',
//					// Optional. Declares that the plugin must be active for sample content import to succeed. Default false.
//					'required_by_sample' => false,
//				),
//			),
//		),
//		'support_page'             => array(
//			'sections' => array(
//				'documentation' => array(
//					'title'       => __( 'Theme Documentation', 'specialty' ),
//					'description' => __( "If you don't want to import our demo sample content, just visit this page and learn how to set things up individually.", 'specialty' ),
//					'link_url'    => 'https://www.cssigniter.com/docs/' . SPECIALTY_NAME . '/',
//				),
//				'kb'            => array(
//					'title'       => __( 'Knowledge Base', 'specialty' ),
//					'description' => __( 'Browse our library of step by step how-to articles, tutorials, and guides to get quick answers.', 'specialty' ),
//					'link_url'    => 'https://www.cssigniter.com/docs/knowledgebase/',
//				),
//				'support'       => array(
//					'title'       => __( 'Request Support', 'specialty' ),
//					'description' => __( 'Got stuck? No worries, just visit our support page, submit your ticket and we will be there for you within 24 hours.', 'specialty' ),
//					'link_url'    => 'https://www.cssigniter.com/support/',
//				),
//			),
//		),
//	);

}

/**
 * User onboarding.
 */
require_once get_theme_file_path( '/inc/onboarding/onboarding-page.php' );
